| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Distribution.Client.Compat.Prelude
Description
This module does two things:
- Acts as a compatibility layer, like
base-compat. - Provides commonly used imports.
This module is a superset of Distribution.Compat.Prelude (which this module re-exports)
Synopsis
- module Distribution.Compat.Prelude.Internal
- eitherParsec :: Parsec a => String -> Either String a
- explicitEitherParsec :: ParsecParser a -> String -> Either String a
- simpleParsec :: Parsec a => String -> Maybe a
- prettyShow :: Pretty a => a -> String
- data Verbosity
- class (CharParsing m, MonadPlus m, MonadFail m) => CabalParsing (m :: Type -> Type)
- class Parsec a where
- parsec :: CabalParsing m => m a
- class Pretty a where
- pretty :: a -> Doc
- prettyVersioned :: CabalSpecVersion -> a -> Doc
Documentation
eitherParsec :: Parsec a => String -> Either String a #
Parse a String with lexemeParsec.
explicitEitherParsec :: ParsecParser a -> String -> Either String a #
Parse a String with given ParsecParser. Trailing whitespace is accepted.
simpleParsec :: Parsec a => String -> Maybe a #
Parse a String with lexemeParsec.
prettyShow :: Pretty a => a -> String #
Rich verbosity, used for the Cabal library interface.
Instances
class (CharParsing m, MonadPlus m, MonadFail m) => CabalParsing (m :: Type -> Type) #
Parsing class which
- can report Cabal parser warnings.
- knows
cabal-versionwe work with
Minimal complete definition
Instances
| CabalParsing ParsecParser # | |
Defined in Distribution.Parsec Methods parsecWarning :: PWarnType -> String -> ParsecParser () # | |
Class for parsing with parsec. Mainly used for .cabal file fields.
For parsing .cabal like file structure, see Distribution.Fields.
Methods
parsec :: CabalParsing m => m a #
Instances
| Parsec DebugInfoLevel # | |
Defined in Distribution.Simple.Compiler Methods parsec :: CabalParsing m => m DebugInfoLevel # | |
| Parsec OptimisationLevel # | |
Defined in Distribution.Simple.Compiler Methods parsec :: CabalParsing m => m OptimisationLevel # | |
| Parsec ProfDetailLevel # | |
Defined in Distribution.Simple.Compiler Methods parsec :: CabalParsing m => m ProfDetailLevel # | |
| Parsec FilePathRoot # | |
Defined in Distribution.Simple.FileMonitor.Types Methods parsec :: CabalParsing m => m FilePathRoot # | |
| Parsec RootedGlob # | |
Defined in Distribution.Simple.FileMonitor.Types Methods parsec :: CabalParsing m => m RootedGlob # | |
| Parsec Glob # | |
Defined in Distribution.Simple.Glob.Internal Methods parsec :: CabalParsing m => m Glob # | |
| Parsec PathTemplate # | |
Defined in Distribution.Simple.InstallDirs Methods parsec :: CabalParsing m => m PathTemplate # | |
| Parsec HaddockTarget # | |
Defined in Distribution.Simple.Setup.Haddock Methods parsec :: CabalParsing m => m HaddockTarget # | |
| Parsec TestShowDetails # | |
Defined in Distribution.Simple.Setup.Test Methods parsec :: CabalParsing m => m TestShowDetails # | |
| Parsec DumpBuildInfo # | |
Defined in Distribution.Types.DumpBuildInfo Methods parsec :: CabalParsing m => m DumpBuildInfo # | |
| Parsec VerbosityFlags # | Parser verbosity
Note: this parser will eat trailing spaces. |
Defined in Distribution.Verbosity Methods parsec :: CabalParsing m => m VerbosityFlags # | |
| Parsec OpenModule # |
|
Defined in Distribution.Backpack Methods parsec :: CabalParsing m => m OpenModule # | |
| Parsec OpenUnitId # |
|
Defined in Distribution.Backpack Methods parsec :: CabalParsing m => m OpenUnitId # | |
| Parsec AbiTag # | |
Defined in Distribution.Compiler Methods parsec :: CabalParsing m => m AbiTag # | |
| Parsec CompilerFlavor # | |
Defined in Distribution.Compiler Methods parsec :: CabalParsing m => m CompilerFlavor # | |
| Parsec CompilerId # | |
Defined in Distribution.Compiler Methods parsec :: CabalParsing m => m CompilerId # | |
| Parsec FilePathNT # | |
Defined in Distribution.FieldGrammar.Newtypes Methods parsec :: CabalParsing m => m FilePathNT # | |
| Parsec SpecLicense # | |
Defined in Distribution.FieldGrammar.Newtypes Methods parsec :: CabalParsing m => m SpecLicense # | |
| Parsec SpecVersion # | |
Defined in Distribution.FieldGrammar.Newtypes Methods parsec :: CabalParsing m => m SpecVersion # | |
| Parsec TestedWith # | |
Defined in Distribution.FieldGrammar.Newtypes Methods parsec :: CabalParsing m => m TestedWith # | |
| Parsec Token # | |
Defined in Distribution.FieldGrammar.Newtypes Methods parsec :: CabalParsing m => m Token # | |
| Parsec Token' # | |
Defined in Distribution.FieldGrammar.Newtypes Methods parsec :: CabalParsing m => m Token' # | |
| Parsec License # | |
Defined in Distribution.License Methods parsec :: CabalParsing m => m License # | |
| Parsec ModuleName # | |
Defined in Distribution.ModuleName Methods parsec :: CabalParsing m => m ModuleName # | |
| Parsec CompatDataDir # | |
Defined in Distribution.PackageDescription.FieldGrammar Methods parsec :: CabalParsing m => m CompatDataDir # | |
| Parsec CompatLicenseFile # | |
Defined in Distribution.PackageDescription.FieldGrammar Methods parsec :: CabalParsing m => m CompatLicenseFile # | |
| Parsec License # |
|
Defined in Distribution.SPDX.License Methods parsec :: CabalParsing m => m License # | |
| Parsec LicenseExceptionId # | |
Defined in Distribution.SPDX.LicenseExceptionId Methods parsec :: CabalParsing m => m LicenseExceptionId # | |
| Parsec LicenseExpression # | |
Defined in Distribution.SPDX.LicenseExpression Methods parsec :: CabalParsing m => m LicenseExpression # | |
| Parsec SimpleLicenseExpression # | |
Defined in Distribution.SPDX.LicenseExpression Methods parsec :: CabalParsing m => m SimpleLicenseExpression # | |
| Parsec LicenseId # |
|
Defined in Distribution.SPDX.LicenseId Methods parsec :: CabalParsing m => m LicenseId # | |
| Parsec LicenseRef # | |
Defined in Distribution.SPDX.LicenseReference Methods parsec :: CabalParsing m => m LicenseRef # | |
| Parsec Arch # | |
Defined in Distribution.System Methods parsec :: CabalParsing m => m Arch # | |
| Parsec OS # | |
Defined in Distribution.System Methods parsec :: CabalParsing m => m OS # | |
| Parsec Platform # | |
Defined in Distribution.System Methods parsec :: CabalParsing m => m Platform # | |
| Parsec AbiDependency # | |
Defined in Distribution.Types.AbiDependency Methods parsec :: CabalParsing m => m AbiDependency # | |
| Parsec AbiHash # | |
Defined in Distribution.Types.AbiHash Methods parsec :: CabalParsing m => m AbiHash # | |
| Parsec BenchmarkType # | |
Defined in Distribution.Types.BenchmarkType Methods parsec :: CabalParsing m => m BenchmarkType # | |
| Parsec BuildType # | |
Defined in Distribution.Types.BuildType Methods parsec :: CabalParsing m => m BuildType # | |
| Parsec ComponentId # | |
Defined in Distribution.Types.ComponentId Methods parsec :: CabalParsing m => m ComponentId # | |
| Parsec ComponentName # | |
Defined in Distribution.Types.ComponentName Methods parsec :: CabalParsing m => m ComponentName # | |
| Parsec Dependency # |
Spaces around colon are not allowed:
Sublibrary syntax is accepted since
|
Defined in Distribution.Types.Dependency Methods parsec :: CabalParsing m => m Dependency # | |
| Parsec ExeDependency # | Examples
|
Defined in Distribution.Types.ExeDependency Methods parsec :: CabalParsing m => m ExeDependency # | |
| Parsec ExecutableScope # | |
Defined in Distribution.Types.ExecutableScope Methods parsec :: CabalParsing m => m ExecutableScope # | |
| Parsec ExposedModule # | |
Defined in Distribution.Types.ExposedModule Methods parsec :: CabalParsing m => m ExposedModule # | |
| Parsec FlagAssignment # |
Issue #7279 was fixed in Cabal-3.8
Since: Cabal-syntax-3.4.0.0 |
Defined in Distribution.Types.Flag Methods parsec :: CabalParsing m => m FlagAssignment # | |
| Parsec FlagName # | |
Defined in Distribution.Types.Flag Methods parsec :: CabalParsing m => m FlagName # | |
| Parsec LibVersionInfo # | |
Defined in Distribution.Types.ForeignLib Methods parsec :: CabalParsing m => m LibVersionInfo # | |
| Parsec ForeignLibOption # | |
Defined in Distribution.Types.ForeignLibOption Methods parsec :: CabalParsing m => m ForeignLibOption # | |
| Parsec ForeignLibType # | |
Defined in Distribution.Types.ForeignLibType Methods parsec :: CabalParsing m => m ForeignLibType # | |
| Parsec IncludeRenaming # | |
Defined in Distribution.Types.IncludeRenaming Methods parsec :: CabalParsing m => m IncludeRenaming # | |
| Parsec CompatPackageKey # | |
Defined in Distribution.Types.InstalledPackageInfo.FieldGrammar Methods parsec :: CabalParsing m => m CompatPackageKey # | |
| Parsec ExposedModules # | |
Defined in Distribution.Types.InstalledPackageInfo.FieldGrammar Methods parsec :: CabalParsing m => m ExposedModules # | |
| Parsec InstWith # | |
Defined in Distribution.Types.InstalledPackageInfo.FieldGrammar Methods parsec :: CabalParsing m => m InstWith # | |
| Parsec SpecLicenseLenient # | |
Defined in Distribution.Types.InstalledPackageInfo.FieldGrammar Methods parsec :: CabalParsing m => m SpecLicenseLenient # | |
| Parsec LegacyExeDependency # | |
Defined in Distribution.Types.LegacyExeDependency Methods parsec :: CabalParsing m => m LegacyExeDependency # | |
| Parsec LibraryVisibility # | |
Defined in Distribution.Types.LibraryVisibility Methods parsec :: CabalParsing m => m LibraryVisibility # | |
| Parsec Mixin # |
Sublibrary syntax is accepted since
|
Defined in Distribution.Types.Mixin Methods parsec :: CabalParsing m => m Mixin # | |
| Parsec Module # | |
Defined in Distribution.Types.Module Methods parsec :: CabalParsing m => m Module # | |
| Parsec ModuleReexport # | |
Defined in Distribution.Types.ModuleReexport Methods parsec :: CabalParsing m => m ModuleReexport # | |
| Parsec ModuleRenaming # | |
Defined in Distribution.Types.ModuleRenaming Methods parsec :: CabalParsing m => m ModuleRenaming # | |
| Parsec MungedPackageId # |
|
Defined in Distribution.Types.MungedPackageId Methods parsec :: CabalParsing m => m MungedPackageId # | |
| Parsec MungedPackageName # |
|
Defined in Distribution.Types.MungedPackageName Methods parsec :: CabalParsing m => m MungedPackageName # | |
| Parsec PackageIdentifier # |
Note: Stricter than
|
Defined in Distribution.Types.PackageId Methods parsec :: CabalParsing m => m PackageIdentifier # | |
| Parsec PackageName # | |
Defined in Distribution.Types.PackageName Methods parsec :: CabalParsing m => m PackageName # | |
| Parsec PackageVersionConstraint # |
|
Defined in Distribution.Types.PackageVersionConstraint Methods parsec :: CabalParsing m => m PackageVersionConstraint # | |
| Parsec PkgconfigDependency # | |
Defined in Distribution.Types.PkgconfigDependency Methods parsec :: CabalParsing m => m PkgconfigDependency # | |
| Parsec PkgconfigName # | |
Defined in Distribution.Types.PkgconfigName Methods parsec :: CabalParsing m => m PkgconfigName # | |
| Parsec PkgconfigVersion # |
|
Defined in Distribution.Types.PkgconfigVersion Methods parsec :: CabalParsing m => m PkgconfigVersion # | |
| Parsec PkgconfigVersionRange # | |
Defined in Distribution.Types.PkgconfigVersionRange Methods parsec :: CabalParsing m => m PkgconfigVersionRange # | |
| Parsec KnownRepoType # | |
Defined in Distribution.Types.SourceRepo Methods parsec :: CabalParsing m => m KnownRepoType # | |
| Parsec RepoKind # | |
Defined in Distribution.Types.SourceRepo Methods parsec :: CabalParsing m => m RepoKind # | |
| Parsec RepoType # | |
Defined in Distribution.Types.SourceRepo Methods parsec :: CabalParsing m => m RepoType # | |
| Parsec TestType # | |
Defined in Distribution.Types.TestType Methods parsec :: CabalParsing m => m TestType # | |
| Parsec DefUnitId # | |
Defined in Distribution.Types.UnitId Methods parsec :: CabalParsing m => m DefUnitId # | |
| Parsec UnitId # | The textual format for |
Defined in Distribution.Types.UnitId Methods parsec :: CabalParsing m => m UnitId # | |
| Parsec UnqualComponentName # | |
Defined in Distribution.Types.UnqualComponentName Methods parsec :: CabalParsing m => m UnqualComponentName # | |
| Parsec Version # | |
Defined in Distribution.Types.Version Methods parsec :: CabalParsing m => m Version # | |
| Parsec VersionRange # |
Small history:
Set operations are introduced in 3.0
Operators are introduced in 1.8. Issues only a warning.
Wild-version ranges are introduced in 1.6. Issues only a warning.
|
Defined in Distribution.Types.VersionRange.Internal Methods parsec :: CabalParsing m => m VersionRange # | |
| Parsec Extension # | |
Defined in Language.Haskell.Extension Methods parsec :: CabalParsing m => m Extension # | |
| Parsec Language # | |
Defined in Language.Haskell.Extension Methods parsec :: CabalParsing m => m Language # | |
| Parsec InstallOutcome Source # | |
Defined in Distribution.Client.BuildReports.Types Methods parsec :: CabalParsing m => m InstallOutcome # | |
| Parsec Outcome Source # | |
Defined in Distribution.Client.BuildReports.Types Methods parsec :: CabalParsing m => m Outcome # | |
| Parsec ReportLevel Source # | |
Defined in Distribution.Client.BuildReports.Types Methods parsec :: CabalParsing m => m ReportLevel # | |
| Parsec PreSolver Source # | |
Defined in Distribution.Client.Dependency.Types Methods parsec :: CabalParsing m => m PreSolver # | |
| Parsec ActiveRepoEntry Source # | |
Defined in Distribution.Client.IndexUtils.ActiveRepos Methods parsec :: CabalParsing m => m ActiveRepoEntry # | |
| Parsec ActiveRepos Source # | Note: empty string is not valid
|
Defined in Distribution.Client.IndexUtils.ActiveRepos Methods parsec :: CabalParsing m => m ActiveRepos # | |
| Parsec CombineStrategy Source # | |
Defined in Distribution.Client.IndexUtils.ActiveRepos Methods parsec :: CabalParsing m => m CombineStrategy # | |
| Parsec RepoIndexState Source # | |
Defined in Distribution.Client.IndexUtils.IndexState Methods parsec :: CabalParsing m => m RepoIndexState # | |
| Parsec TotalIndexState Source # |
|
Defined in Distribution.Client.IndexUtils.IndexState Methods parsec :: CabalParsing m => m TotalIndexState # | |
| Parsec Timestamp Source # | |
Defined in Distribution.Client.IndexUtils.Timestamp Methods parsec :: CabalParsing m => m Timestamp # | |
| Parsec UserConstraint Source # | |
Defined in Distribution.Client.Targets Methods parsec :: CabalParsing m => m UserConstraint # | |
| Parsec AllowNewer Source # | |
Defined in Distribution.Client.Types.AllowNewer Methods parsec :: CabalParsing m => m AllowNewer # | |
| Parsec AllowOlder Source # | |
Defined in Distribution.Client.Types.AllowNewer Methods parsec :: CabalParsing m => m AllowOlder # | |
| Parsec RelaxDepSubject Source # | |
Defined in Distribution.Client.Types.AllowNewer Methods parsec :: CabalParsing m => m RelaxDepSubject # | |
| Parsec RelaxDeps Source # |
This is not a glitch, even it looks like:
|
Defined in Distribution.Client.Types.AllowNewer Methods parsec :: CabalParsing m => m RelaxDeps # | |
| Parsec RelaxedDep Source # | |
Defined in Distribution.Client.Types.AllowNewer Methods parsec :: CabalParsing m => m RelaxedDep # | |
| Parsec InstallMethod Source # | |
Defined in Distribution.Client.Types.InstallMethod Methods parsec :: CabalParsing m => m InstallMethod # | |
| Parsec OverwritePolicy Source # | |
Defined in Distribution.Client.Types.OverwritePolicy Methods parsec :: CabalParsing m => m OverwritePolicy # | |
| Parsec LocalRepo Source # | Note: doesn't parse |
Defined in Distribution.Client.Types.Repo Methods parsec :: CabalParsing m => m LocalRepo # | |
| Parsec RemoteRepo Source # | Note: serialised format represents |
Defined in Distribution.Client.Types.Repo Methods parsec :: CabalParsing m => m RemoteRepo # | |
| Parsec RepoName Source # |
|
Defined in Distribution.Client.Types.RepoName Methods parsec :: CabalParsing m => m RepoName # | |
| Parsec WriteGhcEnvironmentFilesPolicy Source # | |
Defined in Distribution.Client.Types.WriteGhcEnvironmentFilesPolicy Methods parsec :: CabalParsing m => m WriteGhcEnvironmentFilesPolicy # | |
| Parsec AllowNewerNT Source # | |
Defined in Distribution.Client.Utils.Newtypes Methods parsec :: CabalParsing m => m AllowNewerNT # | |
| Parsec AllowOlderNT Source # | |
Defined in Distribution.Client.Utils.Newtypes Methods parsec :: CabalParsing m => m AllowOlderNT # | |
| Parsec KeyThreshold Source # | |
Defined in Distribution.Client.Utils.Newtypes Methods parsec :: CabalParsing m => m KeyThreshold # | |
| Parsec MaxBackjumps Source # | |
Defined in Distribution.Client.Utils.Newtypes Methods parsec :: CabalParsing m => m MaxBackjumps # | |
| Parsec NumJobs Source # | |
Defined in Distribution.Client.Utils.Newtypes Methods parsec :: CabalParsing m => m NumJobs # | |
| Parsec PackageDBNT Source # | |
Defined in Distribution.Client.Utils.Newtypes Methods parsec :: CabalParsing m => m PackageDBNT # | |
| Parsec ProjectConstraints Source # | |
Defined in Distribution.Client.Utils.Newtypes Methods parsec :: CabalParsing m => m ProjectConstraints # | |
| Parsec URI_NT Source # | |
Defined in Distribution.Client.Utils.Newtypes Methods parsec :: CabalParsing m => m URI_NT # | |
| Parsec AllowBootLibInstalls # | |
Defined in Distribution.Solver.Types.Settings Methods parsec :: CabalParsing m => m AllowBootLibInstalls # | |
| Parsec CountConflicts # | |
Defined in Distribution.Solver.Types.Settings Methods parsec :: CabalParsing m => m CountConflicts # | |
| Parsec FineGrainedConflicts # | |
Defined in Distribution.Solver.Types.Settings Methods parsec :: CabalParsing m => m FineGrainedConflicts # | |
| Parsec IndependentGoals # | |
Defined in Distribution.Solver.Types.Settings Methods parsec :: CabalParsing m => m IndependentGoals # | |
| Parsec MinimizeConflictSet # | |
Defined in Distribution.Solver.Types.Settings Methods parsec :: CabalParsing m => m MinimizeConflictSet # | |
| Parsec OnlyConstrained # | |
Defined in Distribution.Solver.Types.Settings Methods parsec :: CabalParsing m => m OnlyConstrained # | |
| Parsec PreferOldest # | |
Defined in Distribution.Solver.Types.Settings Methods parsec :: CabalParsing m => m PreferOldest # | |
| Parsec ReorderGoals # | |
Defined in Distribution.Solver.Types.Settings Methods parsec :: CabalParsing m => m ReorderGoals # | |
| Parsec StrongFlags # | |
Defined in Distribution.Solver.Types.Settings Methods parsec :: CabalParsing m => m StrongFlags # | |
| Parsec Bool # | |
Defined in Distribution.Parsec Methods parsec :: CabalParsing m => m Bool # | |
| Parsec a => Parsec (MQuoted a) # | |
Defined in Distribution.FieldGrammar.Newtypes Methods parsec :: CabalParsing m => m (MQuoted a) # | |
| Parsec a => Parsec (Identity a) # | |
Defined in Distribution.Parsec Methods parsec :: CabalParsing m => m (Identity a) # | |
| Parsec a => Parsec (Last a) # | |
Defined in Distribution.Parsec Methods parsec :: CabalParsing m => m (Last a) # | |
| Parsec (RelativePathNT from to) # | |
Defined in Distribution.FieldGrammar.Newtypes Methods parsec :: CabalParsing m => m (RelativePathNT from to) # | |
| Parsec (SymbolicPathNT from to) # | |
Defined in Distribution.FieldGrammar.Newtypes Methods parsec :: CabalParsing m => m (SymbolicPathNT from to) # | |
| (Newtype a b, Parsec b) => Parsec (Flag' b a) Source # | |
Defined in Distribution.Client.Utils.Parsec Methods parsec :: CabalParsing m => m (Flag' b a) # | |
| (Newtype a b, Sep sep, Parsec b) => Parsec (List sep b a) # | |
Defined in Distribution.FieldGrammar.Newtypes Methods parsec :: CabalParsing m => m (List sep b a) # | |
| (Newtype a b, Sep sep, Parsec b) => Parsec (NonEmpty' sep b a) # | |
Defined in Distribution.FieldGrammar.Newtypes Methods parsec :: CabalParsing m => m (NonEmpty' sep b a) # | |
| (Newtype a b, Ord a, Sep sep, Parsec b) => Parsec (Set' sep b a) # | |
Defined in Distribution.FieldGrammar.Newtypes Methods parsec :: CabalParsing m => m (Set' sep b a) # | |
| Parsec (SymbolicPathX 'AllowAbsolute from to) # | |
Defined in Distribution.Utils.Path Methods parsec :: CabalParsing m => m (SymbolicPathX 'AllowAbsolute from to) # | |
| Parsec (SymbolicPathX 'OnlyRelative from to) # | |
Defined in Distribution.Utils.Path Methods parsec :: CabalParsing m => m (SymbolicPathX 'OnlyRelative from to) # | |
| (Newtype a b, Ord a, Sep sep, Parsec b) => Parsec (NubList' sep b a) Source # | |
Defined in Distribution.Client.Utils.Parsec Methods parsec :: CabalParsing m => m (NubList' sep b a) # | |
Minimal complete definition
Instances
| Pretty FilePathRoot # | |
Defined in Distribution.Simple.FileMonitor.Types | |
| Pretty RootedGlob # | |
Defined in Distribution.Simple.FileMonitor.Types | |
| Pretty Glob # | |
Defined in Distribution.Simple.Glob.Internal | |
| Pretty Suffix # | |
Defined in Distribution.Simple.PreProcess.Types | |
| Pretty HaddockTarget # | |
Defined in Distribution.Simple.Setup.Haddock Methods pretty :: HaddockTarget -> Doc # prettyVersioned :: CabalSpecVersion -> HaddockTarget -> Doc # | |
| Pretty TestShowDetails # | |
Defined in Distribution.Simple.Setup.Test Methods pretty :: TestShowDetails -> Doc # prettyVersioned :: CabalSpecVersion -> TestShowDetails -> Doc # | |
| Pretty VerbosityFlags # | |
Defined in Distribution.Verbosity Methods pretty :: VerbosityFlags -> Doc # prettyVersioned :: CabalSpecVersion -> VerbosityFlags -> Doc # | |
| Pretty OpenModule # | |
Defined in Distribution.Backpack | |
| Pretty OpenUnitId # | |
Defined in Distribution.Backpack | |
| Pretty AbiTag # | |
Defined in Distribution.Compiler | |
| Pretty CompilerFlavor # | |
Defined in Distribution.Compiler Methods pretty :: CompilerFlavor -> Doc # prettyVersioned :: CabalSpecVersion -> CompilerFlavor -> Doc # | |
| Pretty CompilerId # | |
Defined in Distribution.Compiler | |
| Pretty FilePathNT # | |
Defined in Distribution.FieldGrammar.Newtypes | |
| Pretty SpecLicense # | |
Defined in Distribution.FieldGrammar.Newtypes | |
| Pretty SpecVersion # | |
Defined in Distribution.FieldGrammar.Newtypes | |
| Pretty TestedWith # | |
Defined in Distribution.FieldGrammar.Newtypes | |
| Pretty Token # | |
Defined in Distribution.FieldGrammar.Newtypes | |
| Pretty Token' # | |
Defined in Distribution.FieldGrammar.Newtypes | |
| Pretty License # | |
Defined in Distribution.License | |
| Pretty ModuleName # | |
Defined in Distribution.ModuleName | |
| Pretty CompatDataDir # | |
Defined in Distribution.PackageDescription.FieldGrammar Methods pretty :: CompatDataDir -> Doc # prettyVersioned :: CabalSpecVersion -> CompatDataDir -> Doc # | |
| Pretty CompatLicenseFile # | |
Defined in Distribution.PackageDescription.FieldGrammar Methods pretty :: CompatLicenseFile -> Doc # prettyVersioned :: CabalSpecVersion -> CompatLicenseFile -> Doc # | |
| Pretty License # | |
Defined in Distribution.SPDX.License | |
| Pretty LicenseExceptionId # | |
Defined in Distribution.SPDX.LicenseExceptionId Methods pretty :: LicenseExceptionId -> Doc # prettyVersioned :: CabalSpecVersion -> LicenseExceptionId -> Doc # | |
| Pretty LicenseExpression # | |
Defined in Distribution.SPDX.LicenseExpression Methods pretty :: LicenseExpression -> Doc # prettyVersioned :: CabalSpecVersion -> LicenseExpression -> Doc # | |
| Pretty SimpleLicenseExpression # | |
Defined in Distribution.SPDX.LicenseExpression Methods pretty :: SimpleLicenseExpression -> Doc # prettyVersioned :: CabalSpecVersion -> SimpleLicenseExpression -> Doc # | |
| Pretty LicenseId # | |
Defined in Distribution.SPDX.LicenseId | |
| Pretty LicenseRef # | |
Defined in Distribution.SPDX.LicenseReference | |
| Pretty Arch # | |
Defined in Distribution.System | |
| Pretty OS # | |
Defined in Distribution.System | |
| Pretty Platform # | |
Defined in Distribution.System | |
| Pretty AbiDependency # | |
Defined in Distribution.Types.AbiDependency Methods pretty :: AbiDependency -> Doc # prettyVersioned :: CabalSpecVersion -> AbiDependency -> Doc # | |
| Pretty AbiHash # | |
Defined in Distribution.Types.AbiHash | |
| Pretty BenchmarkType # | |
Defined in Distribution.Types.BenchmarkType Methods pretty :: BenchmarkType -> Doc # prettyVersioned :: CabalSpecVersion -> BenchmarkType -> Doc # | |
| Pretty BuildType # | |
Defined in Distribution.Types.BuildType | |
| Pretty ComponentId # | |
Defined in Distribution.Types.ComponentId | |
| Pretty ComponentName # | |
Defined in Distribution.Types.ComponentName Methods pretty :: ComponentName -> Doc # prettyVersioned :: CabalSpecVersion -> ComponentName -> Doc # | |
| Pretty Dependency # |
|
Defined in Distribution.Types.Dependency | |
| Pretty ExeDependency # | |
Defined in Distribution.Types.ExeDependency Methods pretty :: ExeDependency -> Doc # prettyVersioned :: CabalSpecVersion -> ExeDependency -> Doc # | |
| Pretty ExecutableScope # | |
Defined in Distribution.Types.ExecutableScope Methods pretty :: ExecutableScope -> Doc # prettyVersioned :: CabalSpecVersion -> ExecutableScope -> Doc # | |
| Pretty ExposedModule # | |
Defined in Distribution.Types.ExposedModule Methods pretty :: ExposedModule -> Doc # prettyVersioned :: CabalSpecVersion -> ExposedModule -> Doc # | |
| Pretty FlagAssignment # | Since: Cabal-syntax-3.4.0.0 |
Defined in Distribution.Types.Flag Methods pretty :: FlagAssignment -> Doc # prettyVersioned :: CabalSpecVersion -> FlagAssignment -> Doc # | |
| Pretty FlagName # | |
Defined in Distribution.Types.Flag | |
| Pretty LibVersionInfo # | |
Defined in Distribution.Types.ForeignLib Methods pretty :: LibVersionInfo -> Doc # prettyVersioned :: CabalSpecVersion -> LibVersionInfo -> Doc # | |
| Pretty ForeignLibOption # | |
Defined in Distribution.Types.ForeignLibOption Methods pretty :: ForeignLibOption -> Doc # prettyVersioned :: CabalSpecVersion -> ForeignLibOption -> Doc # | |
| Pretty ForeignLibType # | |
Defined in Distribution.Types.ForeignLibType Methods pretty :: ForeignLibType -> Doc # prettyVersioned :: CabalSpecVersion -> ForeignLibType -> Doc # | |
| Pretty IncludeRenaming # | |
Defined in Distribution.Types.IncludeRenaming Methods pretty :: IncludeRenaming -> Doc # prettyVersioned :: CabalSpecVersion -> IncludeRenaming -> Doc # | |
| Pretty CompatPackageKey # | |
Defined in Distribution.Types.InstalledPackageInfo.FieldGrammar Methods pretty :: CompatPackageKey -> Doc # prettyVersioned :: CabalSpecVersion -> CompatPackageKey -> Doc # | |
| Pretty ExposedModules # | |
Defined in Distribution.Types.InstalledPackageInfo.FieldGrammar Methods pretty :: ExposedModules -> Doc # prettyVersioned :: CabalSpecVersion -> ExposedModules -> Doc # | |
| Pretty InstWith # | |
| Pretty SpecLicenseLenient # | |
Defined in Distribution.Types.InstalledPackageInfo.FieldGrammar Methods pretty :: SpecLicenseLenient -> Doc # prettyVersioned :: CabalSpecVersion -> SpecLicenseLenient -> Doc # | |
| Pretty LegacyExeDependency # | |
Defined in Distribution.Types.LegacyExeDependency Methods pretty :: LegacyExeDependency -> Doc # prettyVersioned :: CabalSpecVersion -> LegacyExeDependency -> Doc # | |
| Pretty LibraryVisibility # | |
Defined in Distribution.Types.LibraryVisibility Methods pretty :: LibraryVisibility -> Doc # prettyVersioned :: CabalSpecVersion -> LibraryVisibility -> Doc # | |
| Pretty MissingDependency # | |
Defined in Distribution.Types.MissingDependency Methods pretty :: MissingDependency -> Doc # prettyVersioned :: CabalSpecVersion -> MissingDependency -> Doc # | |
| Pretty Mixin # | |
Defined in Distribution.Types.Mixin | |
| Pretty Module # | |
Defined in Distribution.Types.Module | |
| Pretty ModuleReexport # | |
Defined in Distribution.Types.ModuleReexport Methods pretty :: ModuleReexport -> Doc # prettyVersioned :: CabalSpecVersion -> ModuleReexport -> Doc # | |
| Pretty ModuleRenaming # | |
Defined in Distribution.Types.ModuleRenaming Methods pretty :: ModuleRenaming -> Doc # prettyVersioned :: CabalSpecVersion -> ModuleRenaming -> Doc # | |
| Pretty MungedPackageId # |
|
Defined in Distribution.Types.MungedPackageId Methods pretty :: MungedPackageId -> Doc # prettyVersioned :: CabalSpecVersion -> MungedPackageId -> Doc # | |
| Pretty MungedPackageName # | Computes the package name for a library. If this is the public library, it will just be the original package name; otherwise, it will be a munged package name recording the original package name as well as the name of the internal library. A lot of tooling in the Haskell ecosystem assumes that if something
is installed to the package database with the package name We munge into a reserved namespace, "z-", and encode both the component name and the package name of an internal library using the following format: compat-pkg-name ::= "z-" package-name "-z-" library-name where package-name and library-name have "-" ( "z" + ) "-" segments encoded by adding an extra "z". When we have the public library, the compat-pkg-name is just the package-name, no surprises there!
|
Defined in Distribution.Types.MungedPackageName Methods pretty :: MungedPackageName -> Doc # prettyVersioned :: CabalSpecVersion -> MungedPackageName -> Doc # | |
| Pretty PackageIdentifier # | |
Defined in Distribution.Types.PackageId Methods pretty :: PackageIdentifier -> Doc # prettyVersioned :: CabalSpecVersion -> PackageIdentifier -> Doc # | |
| Pretty PackageName # | |
Defined in Distribution.Types.PackageName | |
| Pretty PackageVersionConstraint # | |
Defined in Distribution.Types.PackageVersionConstraint Methods pretty :: PackageVersionConstraint -> Doc # prettyVersioned :: CabalSpecVersion -> PackageVersionConstraint -> Doc # | |
| Pretty PkgconfigDependency # | |
Defined in Distribution.Types.PkgconfigDependency Methods pretty :: PkgconfigDependency -> Doc # prettyVersioned :: CabalSpecVersion -> PkgconfigDependency -> Doc # | |
| Pretty PkgconfigName # | |
Defined in Distribution.Types.PkgconfigName Methods pretty :: PkgconfigName -> Doc # prettyVersioned :: CabalSpecVersion -> PkgconfigName -> Doc # | |
| Pretty PkgconfigVersion # | |
Defined in Distribution.Types.PkgconfigVersion Methods pretty :: PkgconfigVersion -> Doc # prettyVersioned :: CabalSpecVersion -> PkgconfigVersion -> Doc # | |
| Pretty PkgconfigVersionRange # | |
Defined in Distribution.Types.PkgconfigVersionRange Methods pretty :: PkgconfigVersionRange -> Doc # prettyVersioned :: CabalSpecVersion -> PkgconfigVersionRange -> Doc # | |
| Pretty KnownRepoType # | |
Defined in Distribution.Types.SourceRepo Methods pretty :: KnownRepoType -> Doc # prettyVersioned :: CabalSpecVersion -> KnownRepoType -> Doc # | |
| Pretty RepoKind # | |
Defined in Distribution.Types.SourceRepo | |
| Pretty RepoType # | |
Defined in Distribution.Types.SourceRepo | |
| Pretty TestType # | |
Defined in Distribution.Types.TestType | |
| Pretty DefUnitId # | |
Defined in Distribution.Types.UnitId | |
| Pretty UnitId # | The textual format for |
Defined in Distribution.Types.UnitId | |
| Pretty UnqualComponentName # | |
Defined in Distribution.Types.UnqualComponentName Methods pretty :: UnqualComponentName -> Doc # prettyVersioned :: CabalSpecVersion -> UnqualComponentName -> Doc # | |
| Pretty Version # | |
Defined in Distribution.Types.Version | |
| Pretty VersionRange # |
|
Defined in Distribution.Types.VersionRange.Internal | |
| Pretty Extension # | |
Defined in Language.Haskell.Extension | |
| Pretty KnownExtension # | |
Defined in Language.Haskell.Extension Methods pretty :: KnownExtension -> Doc # prettyVersioned :: CabalSpecVersion -> KnownExtension -> Doc # | |
| Pretty Language # | |
Defined in Language.Haskell.Extension | |
| Pretty InstallOutcome Source # | |
Defined in Distribution.Client.BuildReports.Types Methods pretty :: InstallOutcome -> Doc # prettyVersioned :: CabalSpecVersion -> InstallOutcome -> Doc # | |
| Pretty Outcome Source # | |
Defined in Distribution.Client.BuildReports.Types | |
| Pretty ReportLevel Source # | |
Defined in Distribution.Client.BuildReports.Types | |
| Pretty PreSolver Source # | |
Defined in Distribution.Client.Dependency.Types | |
| Pretty ActiveRepoEntry Source # | |
Defined in Distribution.Client.IndexUtils.ActiveRepos Methods pretty :: ActiveRepoEntry -> Doc # prettyVersioned :: CabalSpecVersion -> ActiveRepoEntry -> Doc # | |
| Pretty ActiveRepos Source # | |
Defined in Distribution.Client.IndexUtils.ActiveRepos | |
| Pretty CombineStrategy Source # | |
Defined in Distribution.Client.IndexUtils.ActiveRepos Methods pretty :: CombineStrategy -> Doc # prettyVersioned :: CabalSpecVersion -> CombineStrategy -> Doc # | |
| Pretty RepoIndexState Source # | |
Defined in Distribution.Client.IndexUtils.IndexState Methods pretty :: RepoIndexState -> Doc # prettyVersioned :: CabalSpecVersion -> RepoIndexState -> Doc # | |
| Pretty TotalIndexState Source # | |
Defined in Distribution.Client.IndexUtils.IndexState Methods pretty :: TotalIndexState -> Doc # prettyVersioned :: CabalSpecVersion -> TotalIndexState -> Doc # | |
| Pretty Timestamp Source # | |
Defined in Distribution.Client.IndexUtils.Timestamp | |
| Pretty UserConstraint Source # | |
Defined in Distribution.Client.Targets Methods pretty :: UserConstraint -> Doc # prettyVersioned :: CabalSpecVersion -> UserConstraint -> Doc # | |
| Pretty RelaxDepSubject Source # | |
Defined in Distribution.Client.Types.AllowNewer Methods pretty :: RelaxDepSubject -> Doc # prettyVersioned :: CabalSpecVersion -> RelaxDepSubject -> Doc # | |
| Pretty RelaxDeps Source # | |
Defined in Distribution.Client.Types.AllowNewer | |
| Pretty RelaxedDep Source # | |
Defined in Distribution.Client.Types.AllowNewer | |
| Pretty InstallMethod Source # | |
Defined in Distribution.Client.Types.InstallMethod Methods pretty :: InstallMethod -> Doc # prettyVersioned :: CabalSpecVersion -> InstallMethod -> Doc # | |
| Pretty OverwritePolicy Source # | |
Defined in Distribution.Client.Types.OverwritePolicy Methods pretty :: OverwritePolicy -> Doc # prettyVersioned :: CabalSpecVersion -> OverwritePolicy -> Doc # | |
| Pretty LocalRepo Source # | |
Defined in Distribution.Client.Types.Repo | |
| Pretty RemoteRepo Source # | |
Defined in Distribution.Client.Types.Repo | |
| Pretty RepoName Source # | |
Defined in Distribution.Client.Types.RepoName | |
| Pretty Component # | |
Defined in Distribution.Solver.Types.ComponentDeps | |
| Pretty ConstraintSource # | |
Defined in Distribution.Solver.Types.ConstraintSource Methods pretty :: ConstraintSource -> Doc # prettyVersioned :: CabalSpecVersion -> ConstraintSource -> Doc # | |
| Pretty ConstraintScope # | |
Defined in Distribution.Solver.Types.PackageConstraint Methods pretty :: ConstraintScope -> Doc # prettyVersioned :: CabalSpecVersion -> ConstraintScope -> Doc # | |
| Pretty PackageConstraint # | |
Defined in Distribution.Solver.Types.PackageConstraint Methods pretty :: PackageConstraint -> Doc # prettyVersioned :: CabalSpecVersion -> PackageConstraint -> Doc # | |
| Pretty PackageProperty # | |
Defined in Distribution.Solver.Types.PackageConstraint Methods pretty :: PackageProperty -> Doc # prettyVersioned :: CabalSpecVersion -> PackageProperty -> Doc # | |
| Pretty ProjectConfigPath # | |
Defined in Distribution.Solver.Types.ProjectConfigPath Methods pretty :: ProjectConfigPath -> Doc # prettyVersioned :: CabalSpecVersion -> ProjectConfigPath -> Doc # | |
| Pretty OnlyConstrained # | |
Defined in Distribution.Solver.Types.Settings Methods pretty :: OnlyConstrained -> Doc # prettyVersioned :: CabalSpecVersion -> OnlyConstrained -> Doc # | |
| Pretty Doc # | Since: Cabal-syntax-3.4.0.0 |
Defined in Distribution.Pretty | |
| Pretty Bool # | |
Defined in Distribution.Pretty | |
| Pretty Int # | |
Defined in Distribution.Pretty | |
| Pretty a => Pretty (MQuoted a) # | |
Defined in Distribution.FieldGrammar.Newtypes | |
| Pretty (PackageLocation local) Source # | |
Defined in Distribution.Client.Types.PackageLocation Methods pretty :: PackageLocation local -> Doc # prettyVersioned :: CabalSpecVersion -> PackageLocation local -> Doc # | |
| Pretty a => Pretty (Identity a) # | |
Defined in Distribution.Pretty | |
| Pretty (RelativePathNT from to) # | |
Defined in Distribution.FieldGrammar.Newtypes Methods pretty :: RelativePathNT from to -> Doc # prettyVersioned :: CabalSpecVersion -> RelativePathNT from to -> Doc # | |
| Pretty (SymbolicPathNT from to) # | |
Defined in Distribution.FieldGrammar.Newtypes Methods pretty :: SymbolicPathNT from to -> Doc # prettyVersioned :: CabalSpecVersion -> SymbolicPathNT from to -> Doc # | |
| (Newtype a b, Pretty b) => Pretty (Flag' b a) Source # | |
Defined in Distribution.Client.Utils.Parsec | |
| (Newtype a b, Sep sep, Pretty b) => Pretty (List sep b a) # | |
Defined in Distribution.FieldGrammar.Newtypes | |
| (Newtype a b, Sep sep, Pretty b) => Pretty (NonEmpty' sep b a) # | |
Defined in Distribution.FieldGrammar.Newtypes Methods pretty :: NonEmpty' sep b a -> Doc # prettyVersioned :: CabalSpecVersion -> NonEmpty' sep b a -> Doc # | |
| (Newtype a b, Sep sep, Pretty b) => Pretty (Set' sep b a) # | |
Defined in Distribution.FieldGrammar.Newtypes | |
| Pretty (SymbolicPathX allowAbsolute from to) # | |
Defined in Distribution.Utils.Path Methods pretty :: SymbolicPathX allowAbsolute from to -> Doc # prettyVersioned :: CabalSpecVersion -> SymbolicPathX allowAbsolute from to -> Doc # | |
| (Newtype a b, Sep sep, Pretty b) => Pretty (NubList' sep b a) Source # | |
Defined in Distribution.Client.Utils.Parsec Methods pretty :: NubList' sep b a -> Doc # prettyVersioned :: CabalSpecVersion -> NubList' sep b a -> Doc # | |