| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Distribution.Client.Utils.Newtypes
Description
This module provides newtype wrappers to be used with Distribution.FieldGrammar.
Whenever we can not provide a Parsec instance for a type, we need to wrap it in a newtype and define the instance.
Documentation
Constructors
| NumJobs | |
Fields
| |
newtype PackageDBNT Source #
Constructors
| PackageDBNT | |
Fields | |
Instances
| Parsec PackageDBNT Source # | |
Defined in Distribution.Client.Utils.Newtypes Methods parsec :: CabalParsing m => m PackageDBNT # | |
| Newtype (Maybe PackageDBCWD) PackageDBNT Source # | |
Defined in Distribution.Client.Utils.Newtypes | |
newtype AllowNewerNT Source #
Constructors
| AllowNewerNT | |
Fields | |
Instances
| Parsec AllowNewerNT Source # | |
Defined in Distribution.Client.Utils.Newtypes Methods parsec :: CabalParsing m => m AllowNewerNT # | |
| Newtype (Maybe AllowNewer) AllowNewerNT Source # | |
Defined in Distribution.Client.Utils.Newtypes | |
newtype AllowOlderNT Source #
Constructors
| AllowOlderNT | |
Fields | |
Instances
| Parsec AllowOlderNT Source # | |
Defined in Distribution.Client.Utils.Newtypes Methods parsec :: CabalParsing m => m AllowOlderNT # | |
| Newtype (Maybe AllowOlder) AllowOlderNT Source # | |
Defined in Distribution.Client.Utils.Newtypes | |
newtype ProjectConstraints Source #
Constructors
| ProjectConstraints | |
Fields | |
Instances
| Parsec ProjectConstraints Source # | |
Defined in Distribution.Client.Utils.Newtypes Methods parsec :: CabalParsing m => m ProjectConstraints # | |
| Newtype (UserConstraint, ConstraintSource) ProjectConstraints Source # | |
Defined in Distribution.Client.Utils.Newtypes Methods pack :: (UserConstraint, ConstraintSource) -> ProjectConstraints # unpack :: ProjectConstraints -> (UserConstraint, ConstraintSource) # | |
newtype MaxBackjumps Source #
Constructors
| MaxBackjumps | |
Fields | |
Instances
| Parsec MaxBackjumps Source # | |
Defined in Distribution.Client.Utils.Newtypes Methods parsec :: CabalParsing m => m MaxBackjumps # | |
| Newtype Int MaxBackjumps Source # | |
Defined in Distribution.Client.Utils.Newtypes | |
newtype KeyThreshold Source #
Constructors
| KeyThreshold | |
Fields | |
Instances
| Parsec KeyThreshold Source # | |
Defined in Distribution.Client.Utils.Newtypes Methods parsec :: CabalParsing m => m KeyThreshold # | |
| Newtype Int KeyThreshold Source # | |
Defined in Distribution.Client.Utils.Newtypes | |