cabal-install
Copyright(c) The University of Glasgow 2002
LicenseBSD-style (see the file libraries/base/LICENSE)
Maintainerlibraries@haskell.org
Portabilityportable
Safe HaskellNone
LanguageHaskell2010

Distribution.Deprecated.ReadP

Description

Mostly re-exports of ReadP, with added type synonym Parser, and added functions skipSpaces1 and readP_to_E.

Synopsis

The ReadP type

data ReadP a #

Instances

Instances details
Alternative ReadP #

Since: base-4.6.0.0

Instance details

Defined in GHC.Internal.Text.ParserCombinators.ReadP

Methods

empty :: ReadP a #

(<|>) :: ReadP a -> ReadP a -> ReadP a #

some :: ReadP a -> ReadP [a] #

many :: ReadP a -> ReadP [a] #

Applicative ReadP #

Since: base-4.6.0.0

Instance details

Defined in GHC.Internal.Text.ParserCombinators.ReadP

Methods

pure :: a -> ReadP a #

(<*>) :: ReadP (a -> b) -> ReadP a -> ReadP b #

liftA2 :: (a -> b -> c) -> ReadP a -> ReadP b -> ReadP c #

(*>) :: ReadP a -> ReadP b -> ReadP b #

(<*) :: ReadP a -> ReadP b -> ReadP a #

Functor ReadP #

Since: base-2.1

Instance details

Defined in GHC.Internal.Text.ParserCombinators.ReadP

Methods

fmap :: (a -> b) -> ReadP a -> ReadP b #

(<$) :: a -> ReadP b -> ReadP a #

Monad ReadP #

Since: base-2.1

Instance details

Defined in GHC.Internal.Text.ParserCombinators.ReadP

Methods

(>>=) :: ReadP a -> (a -> ReadP b) -> ReadP b #

(>>) :: ReadP a -> ReadP b -> ReadP b #

return :: a -> ReadP a #

MonadPlus ReadP #

Since: base-2.1

Instance details

Defined in GHC.Internal.Text.ParserCombinators.ReadP

Methods

mzero :: ReadP a #

mplus :: ReadP a -> ReadP a -> ReadP a #

MonadFail ReadP #

Since: base-4.9.0.0

Instance details

Defined in GHC.Internal.Text.ParserCombinators.ReadP

Methods

fail :: String -> ReadP a #

Primitive operations

get :: ReadP Char #

Consumes and returns the next character. Fails if there is no input left.

look :: ReadP String #

Look-ahead: returns the part of the input that is left, without consuming it.

(+++) :: ReadP a -> ReadP a -> ReadP a infixr 5 #

Symmetric choice.

(<++) :: ReadP a -> ReadP a -> ReadP a infixr 5 #

Local, exclusive, left-biased choice: If left parser locally produces any result at all, then right parser is not used.

gather :: ReadP a -> ReadP (String, a) #

Transforms a parser into one that does the same, but in addition returns the exact characters read. IMPORTANT NOTE: gather gives a runtime error if its first argument is built using any occurrences of readS_to_P.

Other operations

pfail :: ReadP a #

Always fails.

eof :: ReadP () #

Succeeds iff we are at the end of input

satisfy :: (Char -> Bool) -> ReadP Char #

Consumes and returns the next character, if it satisfies the specified predicate.

char :: Char -> ReadP Char #

Parses and returns the specified character.

string :: String -> ReadP String #

Parses and returns the specified string.

munch :: (Char -> Bool) -> ReadP String #

Parses the first zero or more characters satisfying the predicate. Always succeeds, exactly once having consumed all the characters Hence NOT the same as (many (satisfy p))

munch1 :: (Char -> Bool) -> ReadP String #

Parses the first one or more characters satisfying the predicate. Fails if none, else succeeds exactly once having consumed all the characters Hence NOT the same as (many1 (satisfy p))

skipSpaces :: ReadP () #

Skips all whitespace.

skipSpaces1 :: ReadP () Source #

Like skipSpaces but succeeds only if there is at least one whitespace character to skip.

choice :: [ReadP a] -> ReadP a #

Combines all parsers in the specified list.

count :: Int -> ReadP a -> ReadP [a] #

count n p parses n occurrences of p in sequence. A list of results is returned.

between :: ReadP open -> ReadP close -> ReadP a -> ReadP a #

between open close p parses open, followed by p and finally close. Only the value of p is returned.

option :: a -> ReadP a -> ReadP a #

option x p will either parse p or return x without consuming any input.

optional :: ReadP a -> ReadP () #

optional p optionally parses p and always returns ().

many :: ReadP a -> ReadP [a] #

Parses zero or more occurrences of the given parser.

many1 :: ReadP a -> ReadP [a] #

Parses one or more occurrences of the given parser.

skipMany :: ReadP a -> ReadP () #

Like many, but discards the result.

skipMany1 :: ReadP a -> ReadP () #

Like many1, but discards the result.

sepBy :: ReadP a -> ReadP sep -> ReadP [a] #

sepBy p sep parses zero or more occurrences of p, separated by sep. Returns a list of values returned by p.

sepBy1 :: ReadP a -> ReadP sep -> ReadP [a] #

sepBy1 p sep parses one or more occurrences of p, separated by sep. Returns a list of values returned by p.

endBy :: ReadP a -> ReadP sep -> ReadP [a] #

endBy p sep parses zero or more occurrences of p, separated and ended by sep.

endBy1 :: ReadP a -> ReadP sep -> ReadP [a] #

endBy p sep parses one or more occurrences of p, separated and ended by sep.

chainr :: ReadP a -> ReadP (a -> a -> a) -> a -> ReadP a #

chainr p op x parses zero or more occurrences of p, separated by op. Returns a value produced by a right associative application of all functions returned by op. If there are no occurrences of p, x is returned.

chainl :: ReadP a -> ReadP (a -> a -> a) -> a -> ReadP a #

chainl p op x parses zero or more occurrences of p, separated by op. Returns a value produced by a left associative application of all functions returned by op. If there are no occurrences of p, x is returned.

chainl1 :: ReadP a -> ReadP (a -> a -> a) -> ReadP a #

Like chainl, but parses one or more occurrences of p.

chainr1 :: ReadP a -> ReadP (a -> a -> a) -> ReadP a #

Like chainr, but parses one or more occurrences of p.

manyTill :: ReadP a -> ReadP end -> ReadP [a] #

manyTill p end parses zero or more occurrences of p, until end succeeds. Returns a list of values returned by p.

Running a parser

type ReadS a = String -> [(a, String)] #

A parser for a type a, represented as a function that takes a String and returns a list of possible parses as (a,String) pairs.

Note that this kind of backtracking parser is very inefficient; reading a large structure may be quite slow (cf ReadP).

readP_to_S :: ReadP a -> ReadS a #

Converts a parser into a Haskell ReadS-style function. This is the main way in which you can "run" a ReadP parser: the expanded type is readP_to_S :: ReadP a -> String -> [(a,String)]

readS_to_P :: ReadS a -> ReadP a #

Converts a Haskell ReadS-style function into a parser. Warning: This introduces local backtracking in the resulting parser, and therefore a possible inefficiency.

Internal