| Copyright | (c) The University of Glasgow 2002 |
|---|---|
| License | BSD-style (see the file libraries/base/LICENSE) |
| Maintainer | libraries@haskell.org |
| Portability | portable |
| Safe Haskell | None |
| Language | Haskell2010 |
Distribution.Deprecated.ReadP
Description
Mostly re-exports of ReadP, with added type synonym
Parser, and added functions skipSpaces1 and readP_to_E.
Synopsis
- data ReadP a
- get :: ReadP Char
- look :: ReadP String
- (+++) :: ReadP a -> ReadP a -> ReadP a
- (<++) :: ReadP a -> ReadP a -> ReadP a
- gather :: ReadP a -> ReadP (String, a)
- pfail :: ReadP a
- eof :: ReadP ()
- satisfy :: (Char -> Bool) -> ReadP Char
- char :: Char -> ReadP Char
- string :: String -> ReadP String
- munch :: (Char -> Bool) -> ReadP String
- munch1 :: (Char -> Bool) -> ReadP String
- skipSpaces :: ReadP ()
- skipSpaces1 :: ReadP ()
- choice :: [ReadP a] -> ReadP a
- count :: Int -> ReadP a -> ReadP [a]
- between :: ReadP open -> ReadP close -> ReadP a -> ReadP a
- option :: a -> ReadP a -> ReadP a
- optional :: ReadP a -> ReadP ()
- many :: ReadP a -> ReadP [a]
- many1 :: ReadP a -> ReadP [a]
- skipMany :: ReadP a -> ReadP ()
- skipMany1 :: ReadP a -> ReadP ()
- sepBy :: ReadP a -> ReadP sep -> ReadP [a]
- sepBy1 :: ReadP a -> ReadP sep -> ReadP [a]
- endBy :: ReadP a -> ReadP sep -> ReadP [a]
- endBy1 :: ReadP a -> ReadP sep -> ReadP [a]
- chainr :: ReadP a -> ReadP (a -> a -> a) -> a -> ReadP a
- chainl :: ReadP a -> ReadP (a -> a -> a) -> a -> ReadP a
- chainl1 :: ReadP a -> ReadP (a -> a -> a) -> ReadP a
- chainr1 :: ReadP a -> ReadP (a -> a -> a) -> ReadP a
- manyTill :: ReadP a -> ReadP end -> ReadP [a]
- type ReadS a = String -> [(a, String)]
- readP_to_S :: ReadP a -> ReadS a
- readS_to_P :: ReadS a -> ReadP a
- readP_to_E :: (String -> String) -> ReadP a -> ReadE a
- type Parser = ReadP
The ReadP type
Primitive operations
(<++) :: ReadP a -> ReadP a -> ReadP a infixr 5 #
Local, exclusive, left-biased choice: If left parser locally produces any result at all, then right parser is not used.
gather :: ReadP a -> ReadP (String, a) #
Transforms a parser into one that does the same, but
in addition returns the exact characters read.
IMPORTANT NOTE: gather gives a runtime error if its first argument
is built using any occurrences of readS_to_P.
Other operations
satisfy :: (Char -> Bool) -> ReadP Char #
Consumes and returns the next character, if it satisfies the specified predicate.
munch :: (Char -> Bool) -> ReadP String #
Parses the first zero or more characters satisfying the predicate. Always succeeds, exactly once having consumed all the characters Hence NOT the same as (many (satisfy p))
munch1 :: (Char -> Bool) -> ReadP String #
Parses the first one or more characters satisfying the predicate. Fails if none, else succeeds exactly once having consumed all the characters Hence NOT the same as (many1 (satisfy p))
skipSpaces :: ReadP () #
Skips all whitespace.
skipSpaces1 :: ReadP () Source #
Like skipSpaces but succeeds only if there is at least one
whitespace character to skip.
count :: Int -> ReadP a -> ReadP [a] #
count n p parses n occurrences of p in sequence. A list of
results is returned.
between :: ReadP open -> ReadP close -> ReadP a -> ReadP a #
between open close p parses open, followed by p and finally
close. Only the value of p is returned.
option :: a -> ReadP a -> ReadP a #
option x p will either parse p or return x without consuming
any input.
sepBy :: ReadP a -> ReadP sep -> ReadP [a] #
sepBy p sep parses zero or more occurrences of p, separated by sep.
Returns a list of values returned by p.
sepBy1 :: ReadP a -> ReadP sep -> ReadP [a] #
sepBy1 p sep parses one or more occurrences of p, separated by sep.
Returns a list of values returned by p.
endBy :: ReadP a -> ReadP sep -> ReadP [a] #
endBy p sep parses zero or more occurrences of p, separated and ended
by sep.
endBy1 :: ReadP a -> ReadP sep -> ReadP [a] #
endBy p sep parses one or more occurrences of p, separated and ended
by sep.
chainr :: ReadP a -> ReadP (a -> a -> a) -> a -> ReadP a #
chainr p op x parses zero or more occurrences of p, separated by op.
Returns a value produced by a right associative application of all
functions returned by op. If there are no occurrences of p, x is
returned.
chainl :: ReadP a -> ReadP (a -> a -> a) -> a -> ReadP a #
chainl p op x parses zero or more occurrences of p, separated by op.
Returns a value produced by a left associative application of all
functions returned by op. If there are no occurrences of p, x is
returned.
chainl1 :: ReadP a -> ReadP (a -> a -> a) -> ReadP a #
Like chainl, but parses one or more occurrences of p.
chainr1 :: ReadP a -> ReadP (a -> a -> a) -> ReadP a #
Like chainr, but parses one or more occurrences of p.
manyTill :: ReadP a -> ReadP end -> ReadP [a] #
manyTill p end parses zero or more occurrences of p, until end
succeeds. Returns a list of values returned by p.
Running a parser
readP_to_S :: ReadP a -> ReadS a #
Converts a parser into a Haskell ReadS-style function.
This is the main way in which you can "run" a ReadP parser:
the expanded type is
readP_to_S :: ReadP a -> String -> [(a,String)]
readS_to_P :: ReadS a -> ReadP a #
Converts a Haskell ReadS-style function into a parser. Warning: This introduces local backtracking in the resulting parser, and therefore a possible inefficiency.